/* 
   HTTP-DAV client routines,
   Copyright (C) 1998, Joe Orton <joe@orton.demon.co.uk>
                                                                     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef HTTPDAV_H
#define HTTPDAV_H

/* Public Interface: 
 * Call:
 *      http_connect( "www.myhttpserver.com", "80" );
 *      http_userpass( "myusername", "mypassword" );
 * then any of the method function, in any order
 *      http_put, http_delete, dav_move, dav_rmdir, dav_mkcol.
 * lastly:
 *      http_disconnect( );
 *  Note that http_connect does not actually open a connection, rather
 *  performs the hostname lookup
 */


int http_connect( const char *hostname, const int port );
int http_userpass( const char *username, const char *password );
int http_disconnect( void );

int http_put( const char *local, const char *remote );
int http_delete( const char *filename );

int dav_move( const char *from, const char *to );
int dav_rmdir( const char *dirname );
int dav_mkcol( const char *dirname );

/* Private */

int http_parse_status( char *status_line, int *status );
int http_request( const char *method, const char *method_uri,
		  const char *headers, int *, FILE * );
int http_open( void );
int http_close( void );

enum http_auth_t {
    http_auth_basic,
    http_auth_digest, /* TODO: Implement */
    http_auth_none
};

/* The transfer encoding types */
enum http_te_t {
    /* TODO: Support other types */
    http_te_none,
    http_te_chunked,
    http_te_unknown
};

#endif /* HTTPDAV_H */
