/* 
   testdav, a test wrapper for the HTTP-DAV client routines
   Copyright (C) 1998, Joe Orton <joe@orton.demon.co.uk>
                                                                     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Compile with 'make testdav' then run ./testdav for options */

#include <stdio.h>
#include <stdlib.h>

#include "common.h"
#include "socket.h"
#include "httpdav.h"

extern enum debug_t debug_level;

char *progname;

void usage( void ) {
    printf( "Usage: %s <hostname> <port> <action>\n"
	    "Where action is one of:\n"
		"\tupload localfile dest-path\n"
	    "\tdelete dest-path\n"
	    "\tmove from-dest-path to-dest-path\n"
	    "\tmkcol dest-path\n"
	    "\toptions dest-path\n", progname );
    exit(-1);
}

int main( int argc, char **argv ) {
    extern bool http_persistent;
    debug_level = debug_total;
    progname = basename( argv[0] );

    if( argc < 4 ) {
	usage( );
    }
  
    http_persistent = true;

    if( strcmp( argv[3], "move" ) == 0 ) {
	if( argc == 4 ) { printf( "d'oh\n" ); exit(-1); }
	dav_connect( argv[1], atoi( argv[2] ) );
	dav_move( argv[4], argv[5] );
	dav_close( );
    } else if( strcmp( argv[3], "upload" ) == 0 ) {
	if( argc == 4 ) { printf( "d'oh\n" ); exit(-1); }
	dav_connect( argv[1], atoi( argv[2] ) );
	http_put( argv[4], argv[5] );
	dav_close( );
    } else if( strcmp( argv[3], "delete" ) == 0 ) {
	dav_connect( argv[1], atoi( argv[2] ) );
	http_delete( argv[4] );
	dav_close( );
    } else if( strcmp( argv[3], "mkcol" ) == 0 ) {
	dav_connect( argv[1], atoi( argv[2] ) );
	dav_mkcol( argv[4] );
	dav_close( );
    } else if( strcmp( argv[3], "options" ) == 0 ) {
	dav_connect( argv[1], atoi( argv[2] ) );
	http_request( "OPTIONS", argv[4], NULL );
	(void) http_getresponse( );
	dav_close( );
    } else {
	usage( );
    }
	
    return 0;
}
	    
